; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional)
;   buffer.time = time (optional)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas. Each of these
;   buttons or directions is referred to as a "symbol".
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   greater-than (>) - means there must be no other keys pressed or released
;                      between the previous and the current symbol.
;          egs. command = a, >~a   ;press a and release it without having hit
;                                  ;or released any other keys in between
;   You can combine the symbols:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;
;   Note: Successive direction symbols are always expanded in a manner similar
;         to this example:
;           command = F, F
;         is expanded when MUGEN reads it, to become equivalent to:
;           command = F, >~F, >F
;
;   It is recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This makes the command easier
;   to do.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. The default
;   value for this is set in the [Defaults] section below. A typical
;   value is 15.
;
; - buffer.time (optional)
;   Time that the command will be buffered for. If the command is done
;   successfully, then it will be valid for this time. The simplest
;   case is to set this to 1. That means that the command is valid
;   only in the same tick it is performed. With a higher value, such
;   as 3 or 4, you can get a "looser" feel to the command. The result
;   is that combos can become easier to do because you can perform
;   the command early. Attacks just as you regain control (eg. from
;   getting up) also become easier to do. The side effect of this is
;   that the command is continuously asserted, so it will seem as if
;   you had performed the move rapidly in succession during the valid
;   time. To understand this, try setting buffer.time to 30 and hit
;   a fast attack, such as KFM's light punch.
;   The default value for this is set in the [Defaults] section below. 
;   This parameter does not affect hold-only commands (eg. /F). It
;   will be assumed to be 1 for those commands.
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
;
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10


;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 15

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "start"
command = s
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;-| Hold Button |----------------------------------------------------------
; Please define Anim 74140108 in your AIR file if AND ONLY IF you place these
; 7 Hold Button commands immediately after the 11 Single Button and Hold Dir
; commands at the very top of your CMD list, as demonstrated here.
; In this version of the AI code, these commands are only used by the XOR
; method, and thus are optional.  But there remains a possibility that a
; future version of the helper method might be helped by having these
; commands placed here, and Anim 74140108 would then be used to indicate
; that a partner character has a compatible CMD.

[Command]
name = "holda"
command = /a
time = 1

[Command]
name = "holdb"
command = /b
time = 1

[Command]
name = "holdc"
command = /c
time = 1

[Command]
name = "holdx"
command = /x
time = 1

[Command]
name = "holdy"
command = /y
time = 1

[Command]
name = "holdz"
command = /z
time = 1

[Command]
name = "holdstart"
command = /s
time = 1

;--- None of your own command definitions should be above this line. ---

;-| CPU |--------------------------------------------------------------
; Note that if you make any changes to the basic one-button or recovery
; commands, you'll need to make the same changes to their matching commands here
; and/or in the XOR VarSet controller.  That includes things like, for example:
;  * changing the recovery command to use a different combination of buttons.
;  * renaming the b button command as "d", or the start button command as "s".
;  * switching the button names around, e.g. so button y triggers "a" and button a triggers "y".
;  * having more than one way to trigger the same command name.
; If you understand how the XOR method works, the proper changes should be obvious.
; If you don't understand it, then simply disable the lines in the XOR VarSet
; controller that correspond to the commands you've altered.

[Command]
name = "a2"
command = a
time = 1

[Command]
name = "b2"
command = b
time = 1

[Command]
name = "c2"
command = c
time = 1

[Command]
name = "x2"
command = x
time = 1

[Command]
name = "y2"
command = y
time = 1

[Command]
name = "z2"
command = z
time = 1

[Command]
name = "start2"
command = s
time = 1

[Command]
name = "holdfwd2"
command = /$F
time = 1

[Command]
name = "holdback2"
command = /$B
time = 1

[Command]
name = "holdup2"
command = /$U
time = 1

[Command]
name = "holddown2"
command = /$D
time = 1

[Command]
name = "holda2"
command = /a
time = 1

[Command]
name = "holdb2"
command = /b
time = 1

[Command]
name = "holdc2"
command = /c
time = 1

[Command]
name = "holdx2"
command = /x
time = 1

[Command]
name = "holdy2"
command = /y
time = 1

[Command]
name = "holdz2"
command = /z
time = 1

[Command]
name = "holdstart2"
command = /s
time = 1

[Command]
name = "recovery2"
command = x+y
time = 1

;-| Special Motions |--------------------------------------------------------
;
[Command]
name = "JumpFor"
command = ~D, U, F
time = 30

[Command]
name = "JumpFor2"
command = ~D, F, U, F
time = 30

[Command]
name = "JumpBak"
command = ~D, U, B
time = 30

[Command]
name = "JumpBak2"
command = ~D, B, U, B
time = 30

[Command]
name = "JumpUP"
command = ~D, U, U
time = 30

[Command]
name = "JumpBak"
command = /s,UB

[Command]
name = "JumpBak2"
command = /s,B

[Command]
name = "JumpFor"
command = /s,UF

[Command]
name = "JumpFor2"
command = /s,F

[Command]
name = "JumpUP"
command = /s,D
;time = 30

[Command]
name = "SelF"
command = F
time = 2

[Command]
name = "SelB"
command = B
time = 2

;-| Super Motions |--------------------------------------------------------
;The following two have the same name, but different motion.
;Either one will be detected by a "command = TripleKFPalm" trigger.
;Time is set to 20 (instead of default of 15) to make the move
;easier to do.
;
[Command]
name = "TripleKFPalm"
command = ~D, DF, F, D, DF, F, x
time = 20

;-| Special Motions |------------------------------------------------------
[Command]
name = "upper_x"
command = ~F, D, DF, x

[Command]
name = "upper_y"
command = ~F, D, DF, y

[Command]
name = "upper_xy"
command = ~F, D, DF, x+y

[Command]
name = "QCF_x"
command = ~D, DF, F, x

[Command]
name = "QCF_y"
command = ~D, DF, F, y

[Command]
name = "QCF_xy"
command = ~D, DF, F, x+y

[Command]
name = "QCB_x"
command = ~D, DB, B, x

[Command]
name = "QCB_y"
command = ~D, DB, B, y

[Command]
name = "QCB_xy"
command = ~D, DB, B, x+y

[Command]
name = "FF_ab"
command = F, F, a+b

[Command]
name = "FF_a"
command = F, F, a

[Command]
name = "FF_b"
command = F, F, b
;-| Double Tap |-----------------------------------------------------------
[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

[Command]
name = "SupahJump"
;command = ~$D, $U
command = ~$D, $U
time = 5
buffer.time = 2

[Command]
name = "ChargedSupahJump"
;command = ~$D, $U
command = ~12$D, $U
time = 5
buffer.time = 2

[Command]
name = "upper_what"
command = ~15$D, $U, x
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, y
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, z
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, a
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, b
time = 10
[Command]
name = "upper_what"
command = ~15$D, $U, c
time = 10


;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1


;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

; The main purpose of having these next two controllers here at the top of
; StateDef -1 is to make sure the AI helper never changes to a different state,
; nor encounters any VarSets within State -1.
; But they also improve efficiency by preventing Mugen from wasting time
; processing the entire State -1 for the helper.
[State -1, AI Helper Check]
type = ChangeState
trigger1 = IsHelper(9741)
value = 9741

[State -1, AI Helper Check 2]
type = ChangeState
trigger1 = IsHelper(9742)
value = 9742

[State -1, AI Reset]
type = VarSet
triggerall = anim != 5
trigger1 = var(55)=0
trigger2 = (var(52) != [200,290]); || (var(25)!=0))
trigger3 = var(52) = [200,290]
trigger3 = numhelper(810)
trigger3 = (helper(810),var(0)) = (helper(810),var(1))
var(52) = 0
ignorehitpause = 1

[State -1, AI Reset]
type = VarSet
trigger1 = var(25)!=0
trigger1 = roundstate = 3
var(25) = 0
ignorehitpause = 1

; AI-related stuff starts here

[State AI, Jump]
type = VarSet
triggerall = var(52) = 0; || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = !numhelper(3200)
trigger1 = ctrl
trigger1 = var(51) != 52
trigger1 = var(50) >= floor(80 / (var(55)+1) ) + 9
var(52) = ifelse((pos x = [-60,60]),ifelse(random<500,101+random%2,103+random%2),ifelse(frontedgedist<160,ifelse(random<500,100,103),ifelse(random<500,100,101)))
;var(52) = ifelse((pos x = [-60,60]),ifelse(random<500,101,102),ifelse(frontedgedist>160,ifelse(random<500,100,101),ifelse(random<500,100,102))
ignorehitpause = 1

[State AI, Select category]
type = VarSet
triggerall = var(52) = 0; || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = numhelper(810)
triggerall = roundstate = 2
trigger1 = ctrl
trigger1 = var(51) = 52
trigger1 = var(50) = floor(80 / (var(55)+1) ) + 3
trigger2 = stateno=[200,3999]
trigger2 = random< 1 + abs(lifemax-life)
trigger2 = var(51) = 52
trigger2 = time = 4
trigger3 = stateno=[3000,3999]
trigger3 = var(25)=[290,299]
trigger3 = (time%6) = 0
trigger4 = numhelper(3200)
trigger4 = (time%8) = 0
;trigger2 = helper(810),stateno=810
;var(52) = ifelse(var(59)=1&&random<((lifemax-life)/2)&&(helper(810),stateno!=817),406,400+random%7)
var(52) = ifelse((var(59) & floor(exp(1*ln(2)) + 0.5))&&random<((lifemax-life))&&(helper(810),stateno!=817),406,400+random%7)
ignorehitpause = 1

[State AI, Select weapon]
type = VarSet
triggerall = var(52) = 0; || random < 80+(var(55)*2)
triggerall = var(55)
triggerall = numhelper(810)
triggerall = roundstate = 2
trigger1 = ctrl
trigger1 = var(51) = 52
trigger1 = var(50) >= floor(80 / (var(55)+1) ) + 6
trigger2 = stateno=[200,3999]
trigger2 = helper(810),var(0)=0;random< 1 + abs(lifemax-life)
trigger2 = var(51) = 52
trigger2 = time = 6
trigger3 = stateno=[3000,3999]
trigger3 = var(25)=[290,299]
trigger3 = (time%6) = 3
trigger4 = numhelper(3200)
trigger4 = (time%8) = 4
var(52) = 200+random%6;ifelse((helper(810),stateno=811),200+random%6,200+random%5)
ignorehitpause = 1


; AI-related stuff ends here


;===========================================================================
;---------------------------------------------------------------------------
;Stand Light Punch
;p`

[State -1, Jump Up]
type = ChangeState
value = 100
triggerall = (var(55)<5 && (command = "JumpUP")) || var(52) = 100
triggerall = !numhelper(3200)
triggerall = anim != 5
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Jump For]
type = ChangeState
value = 102
triggerall = (var(55)<5 && (command = "JumpFor2")) || var(52) = 102
triggerall = !numhelper(3200)
triggerall = anim != 5
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Jump For]
type = ChangeState
value = 101
triggerall = (var(55)<5 && (command = "JumpFor")) || var(52) = 101
triggerall = !numhelper(3200)
triggerall = anim != 5
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Jump Bak]
type = ChangeState
value = 104
triggerall = (var(55)<5 && (command = "JumpBak2")) || var(52) = 104
triggerall = !numhelper(3200)
triggerall = anim != 5
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Jump Bak]
type = ChangeState
value = 103
triggerall = (var(55)<5 && (command = "JumpBak")) || var(52) = 103
triggerall = !numhelper(3200)
triggerall = anim != 5
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Chaingun]
type = ChangeState
value = 3050
triggerall = var(25) = 290
triggerall = anim != 5
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Friggin' Kintaro]
type = ChangeState
value = 3000
triggerall = var(25) = 291
triggerall = anim != 5
triggerall = !numhelper(3200)
trigger1 = statetype != A
trigger1 = ctrl

[State -1, The Only Way To Be Sure]
type = ChangeState
value = 3100
triggerall = var(25) = 292
triggerall = anim != 5
triggerall = !numhelper(3200)
triggerall = !numhelper(3101)
trigger1 = statetype != A
trigger1 = ctrl

[State -1, FUNNERU]
type = ChangeState
value = 3150
triggerall = var(25) = 293
triggerall = anim != 5
triggerall = !numhelper(1150)
trigger1 = statetype != A
trigger1 = ctrl

[State -1, SHIELDO]
type = ChangeState
value = 3200
triggerall = var(25) = 294
triggerall = anim != 5
triggerall = !numhelper(3200)
trigger1 = statetype != A
trigger1 = ctrl

[State -1, ACE COMBAT]
type = ChangeState
value = 3250
triggerall = var(25) = 295
triggerall = anim != 5
triggerall = !numhelper(3200)
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Mine]
type = ChangeState
value = 230
triggerall = numhelper(1090) < 2
triggerall = anim != 5
triggerall = var(25) = 220
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Scan]
type = ChangeState
value = 221
triggerall = numhelper(1140) < 2
triggerall = anim != 5
triggerall = var(25) = 221
trigger1 = statetype != A
trigger1 = ctrl

[State -1, ENEMY CHASER]
type = ChangeState
value = 222
triggerall = numhelper(1130) < 2
triggerall = anim != 5
triggerall = var(25) = 222
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Ball-bat]
type = ChangeState
value = 223
triggerall = numhelper(1280) < 2
triggerall = anim != 5
triggerall = var(25) = 223
trigger1 = statetype != A
trigger1 = ctrl

[State -1, WHO PUT THESE HERE OW]
type = ChangeState
value = 224
triggerall = numhelper(1180) < 2
triggerall = anim != 5
triggerall = var(25) = 224
trigger1 = statetype != A
trigger1 = ctrl

[State -1, LET'S OIL UP]
type = ChangeState
value = 225
triggerall = numhelper(1190) < 2
triggerall = anim != 5
triggerall = var(25) = 225
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Gun constructed from scraps of Duke's Tripple Machinegun]
type = ChangeState
value = 220
triggerall = var(25) = 240
triggerall = anim != 5
triggerall = !numhelper(3200)
trigger1 = statetype != A
trigger1 = ctrl

[State -1, PUNCH OUT]
type = ChangeState
value = 240
triggerall = var(25) = 241
triggerall = anim != 5
triggerall = !numhelper(3200)
trigger1 = statetype != A
trigger1 = ctrl

[State -1, ZAP ZAP]
type = ChangeState
value = 241
triggerall = var(25) = 242
triggerall = anim != 5
trigger1 = statetype != A
trigger1 = ctrl

[State -1, OPTIC BLAST]
type = ChangeState
value = 242
triggerall = var(25) = 243
triggerall = anim != 5
triggerall = !numhelper(3200)
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Beavis's Addiction]
type = ChangeState
value = 244
triggerall = var(25) = 244
triggerall = anim != 5
triggerall = !numhelper(3200)
trigger1 = statetype != A
trigger1 = ctrl

[State -1, DEVO]
type = ChangeState
value = 245
triggerall = var(25) = 245
triggerall = anim != 5
triggerall = !numhelper(3200)
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Roller]
type = ChangeState
value = 200
triggerall = numhelper(1000) < 3
triggerall = anim != 5
triggerall = var(25) = 200
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Zangief]
type = ChangeState
value = 201
triggerall = numhelper(1010) < 3
triggerall = anim != 5
triggerall = var(25) = 201
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Buggy]
type = ChangeState
value = 202
triggerall = numhelper(1020) < 3
triggerall = anim != 5
triggerall = var(25) = 202
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Rygar]
type = ChangeState
value = 203
triggerall = numhelper(1030) < 3
triggerall = anim != 5
triggerall = var(25) = 203
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Mouser]
type = ChangeState
value = 204
triggerall = numhelper(1040) < 3
triggerall = anim != 5
triggerall = var(25) = 204
trigger1 = statetype != A
trigger1 = ctrl

[State -1, The Reason Tekken 3 Was Never Re-Released]
type = ChangeState
value = 205
triggerall = numhelper(1250) < 1
triggerall = anim != 5
triggerall = var(25) = 231
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Giru]
type = ChangeState
value = 210
triggerall = numhelper(1050) < 3
triggerall = anim != 5
triggerall = var(25) = 210
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Bit]
type = ChangeState
value = 211
triggerall = numhelper(1060) < 3
triggerall = anim != 5
triggerall = var(25) = 211
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Robo-Wasp]
type = ChangeState
value = 212
triggerall = numhelper(1070) < 3
triggerall = anim != 5
triggerall = var(25) = 212
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Roto-Bug]
type = ChangeState
value = 213
triggerall = numhelper(1080) < 3
triggerall = anim != 5
triggerall = var(25) = 213
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Mangemite]
type = ChangeState
value = 214
triggerall = numhelper(1170) < 3
triggerall = anim != 5
triggerall = var(25) = 214
trigger1 = statetype != A
trigger1 = ctrl

[State -1, ElectroSpider]
type = ChangeState
value = 215
triggerall = numhelper(1160) < 3
triggerall = anim != 5
triggerall = var(25) = 215
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Droideka]
type = ChangeState
value = 236
triggerall = numhelper(1310) < 1
triggerall = anim != 5
triggerall = var(25) = 230
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Hedgehog]
type = ChangeState
value = 231
triggerall = numhelper(1100) < 3
triggerall = anim != 5
triggerall = var(25) = 205
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Metool]
type = ChangeState
value = 232
triggerall = numhelper(1110) < 1
triggerall = anim != 5
triggerall = var(25) = 232
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Dennis Hopper]
type = ChangeState
value = 233
triggerall = numhelper(1120) < 1
triggerall = anim != 5
triggerall = var(25) = 233
trigger1 = statetype != A
trigger1 = ctrl

[State -1, SHMUP SHIP]
type = ChangeState
value = 234
triggerall = numhelper(1330) < 1
triggerall = anim != 5
triggerall = var(25) = 234
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Space Marine]
type = ChangeState
value = 235
triggerall = numhelper(1200) < 1
triggerall = anim != 5
triggerall = var(25) = 235
trigger1 = statetype != A
trigger1 = ctrl

[State -1, EDDIE]
type = ChangeState
value = 250
triggerall = numhelper(1220) < 3
triggerall = anim != 5
triggerall = var(25) = 250
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Lucky Two]
type = ChangeState
value = 251
triggerall = numhelper(1230) < 3
triggerall = anim != 5
triggerall = var(25) = 251
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Telly]
type = ChangeState
value = 252
triggerall = numhelper(1270) < 3
triggerall = anim != 5
triggerall = var(25) = 252
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Meta-Knight]
type = ChangeState
value = 253
triggerall = numhelper(1290) < 1
triggerall = anim != 5
triggerall = var(25) = 253
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Adorable Puppy]
type = ChangeState
value = 254
triggerall = numhelper(1300) < 5
triggerall = anim != 5
triggerall = var(25) = 254
trigger1 = statetype != A
trigger1 = ctrl

[State -1, Tired]
type = ChangeState
value = 255
triggerall = numhelper(1320) < 5
triggerall = anim != 5
triggerall = var(25) = 255
trigger1 = statetype != A
trigger1 = ctrl




